"""
Copyright 2023-2023 VMware Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import logging

import click
import httpx

from hcs_cli.service import admin, pki

# Create a logger
logger = logging.getLogger("rootca_migrate_edge")


@click.command(name="migrate_edge", hidden="false")
@click.argument("target_org_id", type=str, required=True)
@click.argument("edge_ids", type=str, required=True)
@click.option("--verbose", "--v", type=bool, is_flag=True, required=False)
def stats(target_org_id: str, edge_ids: str, verbose: bool):
    """one-time edge migration for rootca - cert refresh"""
    logger.info("Started one-time edge migration on org_id: %s, edge_ids: %s", target_org_id, edge_ids)
    edge_id_list = edge_ids.split(",")
    for edge_id in edge_id_list:
        try:
            logger.info("---> org_id: %s, edge_id: %s", target_org_id, edge_id)
            admin.edge.rootca_migrate_private_endpoint_fqdn(edge_id, target_org_id, verbose)
            admin.edge.rootca_migrate_edge_fqdn(edge_id, target_org_id, verbose)
            pki.certificate.rootca_update_edge_calabel(edge_id, target_org_id, "legacy", verbose)
        except httpx.HTTPStatusError as ex:
            logger.error(f"Http Status Code: {ex.response.status_code}")
            logger.error(f"Url: {ex.request.url}")
            logger.error(f"Response Content: {ex.response.text}")
            return
        except Exception as error:
            logger.error(
                f"Failed one-time edge migration on org_id: %s, edge_id: %s due to {str(error)}", target_org_id, edge_id
            )
            return
    logger.info("Finished one-time edge migration on org_id: %s and edge_ids: %s", target_org_id, edge_ids)
